pub enum TryRecvError {
Empty,
Closed,
}Expand description
Error returned by Receiver::try_recv.
Variants
Empty
The queue is empty but senders are still alive.
Closed
All senders have been dropped and the queue is empty.