pub struct Receiver<T> { /* private fields */ }Expand description
Receiving half of a oneshot channel. Implements Future and resolves to the sent value.
Implementations
Sourceimpl<T> Receiver<T>
impl<T> Receiver<T>
Sourcepub async fn recv(self) -> Result<T, RecvError>
pub async fn recv(self) -> Result<T, RecvError>
Receives the value, parking until it arrives.
Returns Err if the sender was dropped without sending a value.
Sourcepub fn try_recv(&mut self) -> Result<T, TryRecvError>
pub fn try_recv(&mut self) -> Result<T, TryRecvError>
Receives without waiting.
Returns Err(Empty) if no value has been sent yet, or Err(Closed) if the sender was
dropped without sending.