pub fn now<I: Io>() -> Duration
Retrieves the current duration since the epoch start start from I/O. The type parameter I must match the Io implementation this runtime was initialized with.
I
Io
Panics if called outside of an active runtime or if I does not match the runtime’s I/O type.